==> fotoalbum-0.33.tar.bz2: fotoalbum-0.33/src/base/treepiclink.cpp <==
/*
 * Copyright (C) 2005, 2010  Jens Wilhelm Wulf, j dot w dot wulf at gmx dot net
 * Licensed under the GNU General Public License version 2.
 */

#include "treepiclink.h"

#include <iostream>

#include "xmldefs.h"
#include "treeview.h"

std::string TreePicLink::getText()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getText());
  else
    return("[error: link destination not found]");
}

std::string TreePicLink::getSomeText(eText whichText)
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getSomeText(whichText));
  else
    return("[error: link destination not found]");
}

TreePicLink::TreePicLink(TreeItem* prev, TreeGroupBase* parent) : TreePicBase(prev, parent)
{
  linkptr = (TreePicBase*)0;
}

TreePicLink::TreePicLink(TreeItem* prev, TreeGroupBase* parent, TreeItem* dest) : TreePicBase(prev, parent)
{
  linkptr = (TreePicBase*)dest;
  linkID  = dest->getID();
}

TreePicLink::~TreePicLink()
{
}

int TreePicLink::loadFromXML_all(SimpleXMLTransfer*    source,
                                 LinkInfo*             links)
{
  TreeItem::loadFromXML_all(source, links);
  linkID = source->attributeAsInt(XMLNAME_LINK);
  return(0);
}
   
int TreePicLink::saveToXML_all(SimpleXMLTransfer* dest, bool fConvLinks, int nVersion)
{
  TreeItem::saveToXML_all(dest, fConvLinks, nVersion);

  dest->setName(XMLNAME_SAVE_ITEM);
  
  if (fConvLinks)  
  {
    // I am a link in a 'virtual view' like chronological view or 
    // search result. If (linkID == 0), then it is perfect to
    // save data and not the link ID. But if (linkID!=0), then I 
    // don't know wether the link target does exist in this virtual 
    // view or not -- I assume that it is not, just to be save. However,
    // the link is broken in this case.
    JWWDateTime dt = getDT();
    std::string keywords = getKeywords();
    std::string comment  = getComment();
    
    dest->addAttribute(XMLNAME_SAVE_TYPE,     XMLNAME_SAVE_TYPE_PIC);
    dest->addAttribute(XMLNAME_SAVE_PATH,     getPath());
    if (!keywords.empty())
      dest->addAttribute(XMLNAME_SAVE_KEYWORDS, keywords);
    if (!comment.empty())
      dest->addAttribute(XMLNAME_SAVE_COMMENT,  comment);
    if (dt.nTime != 0)
      dest->addAttribute(XMLNAME_SAVE_TIME,     dt.nTime);
    if (dt.nDate != 0)
      dest->addAttribute(XMLNAME_SAVE_DATE,     dt.nDate);    
  }
  else
  {
    // I am a real link
    dest->addAttribute(XMLNAME_SAVE_TYPE, XMLNAME_SAVE_TYPE_PICLINK);
    dest->addAttribute(XMLNAME_SAVE_LINK, linkID);
  }    
    
  return(0);
}

enum TreeItem::eItemLinkType TreePicLink::getLinkType()
{
  return(LINK);
}

std::string TreePicLink::getPath()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getPath());
  else
    return("[error: link destination not found]");
}

std::string TreePicLink::getComment()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getComment());
  else
    return("[error: link destination not found]");
}

std::string TreePicLink::getKeywords()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getKeywords());
  else
    return("");
}

std::string TreePicLink::getTimeString()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getTimeString());
  else
    return("");
}

std::string TreePicLink::getDateString()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getDateString());
  else
    return("");
}

bool TreePicLink::hasTime()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->hasTime());
  else
    return(false);
}

bool TreePicLink::hasDate()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->hasDate());
  else
    return(false);
}

JWWDateTime TreePicLink::getDateTime()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getDateTime());
  else
  {
    JWWDateTime dt;
    dt.nDate = 0;
    dt.nTime = 0;
    return(dt);
  }
}

std::string TreePicLink::getDescr(int level, bool fShort)
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getDescr(level, fShort));
  else
    return("[error: link destination not found]");
}

TreePicBase* TreePicLink::getDataSource()
{
  if (linkptr != (TreePicBase*)0)
  {
    if (linkptr->getLinkType() == TreeItem::LINK)
      return(((TreePicLink*)linkptr)->getDataSource());
    else
      return(linkptr);
  }
  else
    return((TreePicBase*)0);
}

int  TreePicLink::connectLinks(LinkInfo* links)
{
  // My comment is not a original one, so its links are not counted.

  // --- connect my own link ----------------------------------------
  return(links->countLinkCount((TreeItem**)(&linkptr), linkID, TreeItem::PIC, true));
}

void TreePicLink::setComment(const char* nC)
{
  if (linkptr != (TreePicBase*)0)
    linkptr->setComment(nC);  
}

void TreePicLink::setKeywords(const char* nK)
{
  if (linkptr != (TreePicBase*)0)
    linkptr->setKeywords(nK);  
}

int TreePicLink::setDate(const char* nD)
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->setDate(nD));
  else
    return(-1);
}

int TreePicLink::setTime(const char* nT)
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->setTime(nT));
  else
    return(-1);
}

JWWDateTime TreePicLink::getDT()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getDT());
  else
  {
    JWWDateTime dummy;
    dummy.nDate = 0;
    dummy.nTime = 0;
    return(dummy);
  }
}

unsigned int TreePicLink::getYear()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getYear());
  else
    return(0);
}

void TreePicLink::timeshift(int nSec)
{
  if (linkptr != (TreePicBase*)0)
    linkptr->timeshift(nSec);
}

bool TreePicLink::isHidden()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->isHidden());
  else
    return(false);
}

==> fotoalbum-0.104.tar.bz2: fotoalbum-0.104/src/base/treepiclink.cpp <==
/*
 * Copyright (C) 2005, 2010  Jens Wilhelm Wulf, j dot w dot wulf at gmx dot net
 * Licensed under the GNU General Public License version 2.
 */

#include "treepiclink.h"

#include <iostream>

#include "xmldefs.h"
#include "treeview.h"

std::string TreePicLink::getText()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getText());
  else
    return("[error: link destination not found]");
}

std::string TreePicLink::getSomeText(eText whichText)
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getSomeText(whichText));
  else
    return("[error: link destination not found]");
}

TreePicLink::TreePicLink(TreeItem* prev, TreeGroupBase* parent) : TreePicBase(prev, parent)
{
  linkptr = (TreePicBase*)0;
}

TreePicLink::TreePicLink(TreeItem* prev, TreeGroupBase* parent, TreeItem* dest) : TreePicBase(prev, parent)
{
  linkptr = (TreePicBase*)dest;
  linkID  = dest->getID();
}

TreePicLink::~TreePicLink()
{
}

int TreePicLink::loadFromXML_all(SimpleXMLTransfer*    source,
                                 LinkInfo*             links)
{
  TreeItem::loadFromXML_all(source, links);
  linkID = source->attributeAsInt(XMLNAME_LINK);
  return(0);
}
   
int TreePicLink::saveToXML_all(SimpleXMLTransfer* dest, bool fConvLinks, int nVersion)
{
  TreeItem::saveToXML_all(dest, fConvLinks, nVersion);

  dest->setName(XMLNAME_SAVE_ITEM);
  
  if (fConvLinks)  
  {
    // I am a link in a 'virtual view' like chronological view or 
    // search result. If (linkID == 0), then it is perfect to
    // save data and not the link ID. But if (linkID!=0), then I 
    // don't know wether the link target does exist in this virtual 
    // view or not -- I assume that it is not, just to be save. However,
    // the link is broken in this case.
    JWWDateTime dt = getDT();
    std::string keywords = getKeywords();
    std::string comment  = getComment();
    
    dest->addAttribute(XMLNAME_SAVE_TYPE,     XMLNAME_SAVE_TYPE_PIC);
    dest->addAttribute(XMLNAME_SAVE_PATH,     TreePicData::EncodePath(getPath()));
    if (!keywords.empty())
      dest->addAttribute(XMLNAME_SAVE_KEYWORDS, keywords);
    if (!comment.empty())
      dest->addAttribute(XMLNAME_SAVE_COMMENT,  comment);
    if (dt.nTime != 0)
      dest->addAttribute(XMLNAME_SAVE_TIME,     dt.nTime);
    if (dt.nDate != 0)
      dest->addAttribute(XMLNAME_SAVE_DATE,     dt.nDate);    
  }
  else
  {
    // I am a real link
    dest->addAttribute(XMLNAME_SAVE_TYPE, XMLNAME_SAVE_TYPE_PICLINK);
    dest->addAttribute(XMLNAME_SAVE_LINK, linkID);
  }    
    
  return(0);
}

enum TreeItem::eItemLinkType TreePicLink::getLinkType()
{
  return(LINK);
}

std::string TreePicLink::getPath()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getPath());
  else
    return("[error: link destination not found]");
}

std::string TreePicLink::getComment()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getComment());
  else
    return("[error: link destination not found]");
}

std::string TreePicLink::getKeywords()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getKeywords());
  else
    return("");
}

std::string TreePicLink::getTimeString()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getTimeString());
  else
    return("");
}

std::string TreePicLink::getDateString()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getDateString());
  else
    return("");
}

bool TreePicLink::hasTime()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->hasTime());
  else
    return(false);
}

bool TreePicLink::hasDate()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->hasDate());
  else
    return(false);
}

JWWDateTime TreePicLink::getDateTime()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getDateTime());
  else
  {
    JWWDateTime dt;
    dt.nDate = 0;
    dt.nTime = 0;
    return(dt);
  }
}

std::string TreePicLink::getDescr(int level, bool fShort)
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getDescr(level, fShort));
  else
    return("[error: link destination not found]");
}

TreePicBase* TreePicLink::getDataSource()
{
  if (linkptr != (TreePicBase*)0)
  {
    if (linkptr->getLinkType() == TreeItem::LINK)
      return(((TreePicLink*)linkptr)->getDataSource());
    else
      return(linkptr);
  }
  else
    return((TreePicBase*)0);
}

int  TreePicLink::connectLinks(LinkInfo* links)
{
  // My comment is not a original one, so its links are not counted.

  // --- connect my own link ----------------------------------------
  return(links->countLinkCount((TreeItem**)(&linkptr), linkID, TreeItem::PIC, true));
}

void TreePicLink::setComment(const char* nC)
{
  if (linkptr != (TreePicBase*)0)
    linkptr->setComment(nC);  
}

void TreePicLink::setKeywords(const char* nK)
{
  if (linkptr != (TreePicBase*)0)
    linkptr->setKeywords(nK);  
}

int TreePicLink::setDate(const char* nD)
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->setDate(nD));
  else
    return(-1);
}

int TreePicLink::setTime(const char* nT)
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->setTime(nT));
  else
    return(-1);
}

JWWDateTime TreePicLink::getDT()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getDT());
  else
  {
    JWWDateTime dummy;
    dummy.nDate = 0;
    dummy.nTime = 0;
    return(dummy);
  }
}

unsigned int TreePicLink::getYear()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->getYear());
  else
    return(0);
}

void TreePicLink::timeshift(int nSec)
{
  if (linkptr != (TreePicBase*)0)
    linkptr->timeshift(nSec);
}

bool TreePicLink::isHidden()
{
  if (linkptr != (TreePicBase*)0)
    return(linkptr->isHidden());
  else
    return(false);
}
